@@ -10,7 +10,16 @@
 #' @param extend options:("yes", NULL): \code{NULL} (default) Sets the \code{"extendInt"} argument from \link{uniroot}.
 #' @return For \code{(binary=FALSE)} returns the degree certainty the difference in sample means is zero [0,1].
 #'
-#' For \code{(binary=TRUE)} returns \code{"Control Mean"}, \code{"Treatment Mean"}, \code{"Grand Mean"}, \code{"Control CDF"}, \code{"Treatment CDF"}, the certainty of the same population statistic \code{"Certainty"}, the effect size of the treatment for a specified confidence interval with \code{"Lower Bound Effect"} and \code{"Upper Bound Effect"}.
+#' For \code{(binary=TRUE)} returns:
+#' \itemize{
+#' \item{\code{"Control Mean"}}
+#' \item{\code{"Treatment Mean"}}
+#' \item{\code{"Grand Mean"}}
+#' \item{\code{"Control CDF"}}
+#' \item{\code{"Treatment CDF"}}
+#' \item{\code{"Certainty"}} the certainty of the same population statistic
+#' \item{\code{"Lower Bound Effect"} and \code{"Upper Bound Effect"}} the effect size of the treatment for the specified confidence interval
+#' }
 #' @note If endpoint error is generated, set \code{(extend="yes")}.
 #' @keywords ANOVA, effect size
 #' @author Fred Viole, OVVO Financial Systems
@@ -73,14 +82,18 @@ NNS.ANOVA<- function(control,treatment,confidence.interval=0.95,pairwise=FALSE,p
         return(c("Certainty"=NNS.ANOVA.rho))
     } else {
 
-          certainties = list()
-          i=1L
-          while(i <=ncol(A)){
-            certainties[[i]]=sapply(1:ncol(A), function(b) NNS.ANOVA(cbind(A[,i],A[,b])))
+          raw.certainties = list()
+          n <- ncol(A)
+          for(i in 1:(n-1)){
+            raw.certainties[[i]]=sapply((i+1):n, function(b) NNS.ANOVA(cbind(A[,i],A[,b])))
             i=i+1
           }
 
-          certainties=do.call(rbind,certainties)
+          certainties <- matrix(, n, n)
+          certainties[lower.tri(certainties, diag=FALSE)] <- unlist(raw.certainties)
+          diag(certainties) <- 1
+          certainties = pmax(certainties, t(certainties), na.rm=TRUE)
+
           colnames(certainties) = colnames(A)
           rownames(certainties) = colnames(A)
 
