@@ -57,16 +57,16 @@ NNS.cor.hd <- function (x,plot=FALSE,independence.overlay=FALSE){
         clpm.box$vb[1,] <- replace(clpm.box$vb[1,], clpm.box$vb[1,] == -1, min(A[,1]))
         clpm.box$vb[2,] <- replace(clpm.box$vb[2,], clpm.box$vb[2,] == -1, min(A[,2]))
         clpm.box$vb[3,] <- replace(clpm.box$vb[3,], clpm.box$vb[3,] == -1, min(A[,3]))
-        clpm.box$vb[1,] <- replace(clpm.box$vb[1,], clpm.box$vb[1,] == 1, (max(A[,1])+min(A[,1]))/2)
-        clpm.box$vb[2,] <- replace(clpm.box$vb[2,], clpm.box$vb[2,] == 1, (max(A[,2])+min(A[,2]))/2)
-        clpm.box$vb[3,] <- replace(clpm.box$vb[3,], clpm.box$vb[3,] == 1, (max(A[,3])+min(A[,3]))/2)
+        clpm.box$vb[1,] <- replace(clpm.box$vb[1,], clpm.box$vb[1,] == 1, mean(A[,1]))
+        clpm.box$vb[2,] <- replace(clpm.box$vb[2,], clpm.box$vb[2,] == 1, mean(A[,2]))
+        clpm.box$vb[3,] <- replace(clpm.box$vb[3,], clpm.box$vb[3,] == 1, mean(A[,3]))
 
         cupm.box$vb[1,] <- replace(cupm.box$vb[1,], cupm.box$vb[1,] == 1, max(A[,1]))
         cupm.box$vb[2,] <- replace(cupm.box$vb[2,], cupm.box$vb[2,] == 1, max(A[,2]))
         cupm.box$vb[3,] <- replace(cupm.box$vb[3,], cupm.box$vb[3,] == 1, max(A[,3]))
-        cupm.box$vb[1,] <- replace(cupm.box$vb[1,], cupm.box$vb[1,] == -1, (max(A[,1])+min(A[,1]))/2)
-        cupm.box$vb[2,] <- replace(cupm.box$vb[2,], cupm.box$vb[2,] == -1, (max(A[,2])+min(A[,2]))/2)
-        cupm.box$vb[3,] <- replace(cupm.box$vb[3,], cupm.box$vb[3,] == -1, (max(A[,3])+min(A[,3]))/2)
+        cupm.box$vb[1,] <- replace(cupm.box$vb[1,], cupm.box$vb[1,] == -1, mean(A[,1]))
+        cupm.box$vb[2,] <- replace(cupm.box$vb[2,], cupm.box$vb[2,] == -1, mean(A[,2]))
+        cupm.box$vb[3,] <- replace(cupm.box$vb[3,], cupm.box$vb[3,] == -1, mean(A[,3]))
 
 
         shade3d(clpm.box)
