@@ -24,21 +24,21 @@ NNS.FSD <- function(x,y){
   Combined_sort = sort(Combined, decreasing=FALSE)
 
  ## Indicator function ***for all values of x and y*** as the CDF target
-
-  x.fsd.y=sum((LPM(0,Combined_sort,y)-LPM(0,Combined_sort,x))>=0)
-
-  y.fsd.x=sum((LPM(0,Combined_sort,x)-LPM(0,Combined_sort,y))>=0)
-
   LPM_x_sort=LPM(0,Combined_sort,x)
   LPM_y_sort=LPM(0,Combined_sort,y)
 
+  x.fsd.y=sum((LPM_y_sort-LPM_x_sort)>=0)
+
+  y.fsd.x=sum((LPM_x_sort-LPM_y_sort)>=0)
+
+
     plot(Combined_sort,LPM_x_sort, type = "l", lwd =3,col = "red", main = "FSD", ylab = "Probability of Cumulative Distribution")
     lines(Combined_sort,LPM_y_sort, type = "l", lwd =3,col = "blue")
     legend("topleft", c("X","Y"), lwd=10,
            col=c("red","blue"))
 
      ## Verification of ***0 instances*** of CDFx > CDFy, and conversely of CDFy > CDFx
-    ifelse (x.fsd.y==length(Combined) & min(x)>=min(y),"X FSD Y",
-           ifelse (y.fsd.x==length(Combined) & min(y)>=min(x),"Y FSD X","NO FSD EXISTS"))
+    ifelse (x.fsd.y==length(Combined) & min(x)>=min(y) & !identical(LPM_x_sort,LPM_y_sort),"X FSD Y",
+           ifelse (y.fsd.x==length(Combined) & min(y)>=min(x) & !identical(LPM_x_sort,LPM_y_sort),"Y FSD X","NO FSD EXISTS"))
 }
 
