@@ -6,6 +6,8 @@
 #' @param y a numeric or factor vector with compatible dimsensions to \code{x}.
 #' @param order integer; Controls the number of partial moment quadrant means.  Users are encouraged to try different \code{(order=...)} integer settings with \code{(noise.reduction="off")}.  \code{(order="max")} will force a limit condition perfect fit.
 #' @param stn numeric [0,1]; Signal to noise parameter, sets the threshold of \code{(NNS.dep)} which reduces \code{("order")} when \code{(order=NULL)}.  Defaults to 0.99 to ensure high dependence for higher \code{("order")} and endpoint determination.  \code{(noise.reduction="off")} sets \code{(stn=0)} to allow for maximum fit.
+#' @param dim.red logical; \code{FALSE} (default).  Set to \code{(dim.red=TRUE)} for dimension reduction using synthetic X*.
+#' @param dim.red.method options: ("cor", "cause", "both") method for determining synthetic X* coefficients.  \code{(dim.red.method="cor")} (default) uses \link{NNS.cor} for nonlinear correlation weights, while \code{(dim.red.method="cause")} uses \link{NNS.caus} for causal weights.  \code{(dim.red.method="both")} averages both methods for further feature engineering.
 #' @param type \code{NULL} (default).  To perform logistic regression, set to \code{(type = "LOGIT")}.  To perform a classification, set to \code{(type = "CLASS")}.
 #' @param point.est a numeric or factor vector with compatible dimsensions to \code{x}.  Returns the fitted value \code{y.hat} for any value of \code{x}.
 #' @param location Sets the legend location within the plot, per the \code{x} and \code{y} co-ordinates used in base graphics \link{legend}.
@@ -63,10 +65,16 @@
 #' @note Please ensure \code{point.est} is of compatible dimensions to \code{x}, error message will ensue if not compatible.  Also, upon visual inspection of the data, if a highly periodic variable is observed set \code{(stn=0)} or \code{(order="max")} to ensure a proper fit.
 #'
 #' Identical regressors can be used as long as they do not share the same name. For instance, \code{NNS.reg(cbind(x,1*x),y)} will work as \code{NNS.reg} is not affected by multicollinearity.
+#'
+#' \code{NNS (>= v.0.3.4)} has repurposed parameter \code{(type="CLASS")}.  \code{(type="CLASS")} is now restricted to signifying a classification analysis for \code{NNS.reg} while \code{(dim.red=TRUE)} enables dimension reduction regressions.
+#'
 #' @keywords nonlinear regression, classifier
 #' @author Fred Viole, OVVO Financial Systems
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
 #' \url{http://amzn.com/1490523995}
+#'
+#' Vinod, H. and Viole, F. (2017) "Nonparametric Regression Using Clusters"
+#' \url{https://link.springer.com/article/10.1007/s10614-017-9713-5}
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100)
@@ -90,12 +98,16 @@
 #'
 #' ## For Multiple Regression based on Synthetic X* (Dimension Reduction):
 #' x<-cbind(rnorm(100),rnorm(100),rnorm(100)); y<-rnorm(100)
-#' NNS.reg(x,y,point.est=c(.25,.5,.75),type="CLASS")
+#' NNS.reg(x,y,point.est=c(.25,.5,.75),dim.red=TRUE)
 #'
-#' ## IRIS dataset example:
-#' #Dimension Reduction:
-#' NNS.reg(iris[,1:4],iris[,5],type="CLASS",order=5)
-#' #Multiple Regression:
+#' ## IRIS dataset examples:
+#' # Dimension Reduction:
+#' NNS.reg(iris[,1:4],iris[,5],dim.red=TRUE,order=5)
+#'
+#' # Dimension Reduction using causal weights:
+#' NNS.reg(iris[,1:4],iris[,5],dim.red=TRUE,dim.red.method="cause",order=5)
+#'
+#' # Multiple Regression:
 #' NNS.reg(iris[,1:4],iris[,5],order=2,noise.reduction="off")
 #'
 #' ## To call fitted values:
@@ -112,14 +124,16 @@
 NNS.reg = function (x,y,
                     order=NULL,
                     stn=.99,
+                    dim.red=FALSE,
+                    dim.red.method="cor",
                     type = NULL,
                     point.est = NULL,
-                    location = 'top',
+                    location = "top",
                     return.values = TRUE,
                     plot = TRUE, plot.regions=FALSE,residual.plot=TRUE,
                     threshold = 0,
                     n.best=NULL,
-                    noise.reduction='mean',
+                    noise.reduction="mean",
                     norm=NULL,
                     dist="L2",multivariate.call=FALSE){
 
@@ -134,6 +148,11 @@ NNS.reg = function (x,y,
   np = nrow(point.est)
 
   if(noise.reduction=='off'){stn=0}
+  if(!is.null(type)){
+  if(type=="CLASS"){
+    if(is.null(n.best)){n.best=1}
+  }}
+
 
   y=as.numeric(y)
   if(is.null(names(original.y))){y.label="Y"}else{y.label=names(y)}
@@ -153,15 +172,15 @@ NNS.reg = function (x,y,
     if(ncol(original.variable)==1){
       x=original.variable
     } else {
-      if(is.null(type)){
+      if(dim.red==FALSE){
         if(!is.null(original.columns)){
           if(is.null(n.best)){n.best=2*original.columns} }
         else{if(is.null(n.best)){n.best=2} }
 
         return(NNS.M.reg(x,y,point.est=point.est,plot=plot,residual.plot=plot,order=order,n.best=n.best,type=type,location=location,noise.reduction=noise.reduction,norm = norm,dist=dist,stn = stn,return.values=return.values,plot.regions = plot.regions))
-      } # Multivariate NULL type
+      } # Multivariate dim.red==FALSE
           else{
-              if(type=="CLASS"){
+              if(dim.red==TRUE){
 
                 if(is.null(original.names)){
                   colnames.list=list()
@@ -173,9 +192,31 @@ NNS.reg = function (x,y,
                   y= as.numeric(y)
 
                   x.star.matrix = matrix(nrow=length(y))
-
                   x.star.dep = NNS.dep(cbind(x,y))
-                  x.star.coef = x.star.dep$Correlation[-(ncol(x)+1),(ncol(x)+1)]
+
+
+                  if(dim.red.method=="cor"){
+                    x.star.coef = x.star.dep$Correlation[-(ncol(x)+1),(ncol(x)+1)]
+                  }
+
+                  if(dim.red.method=="cause"){
+                    x.star.coef=numeric()
+                    for(i in 1:ncol(x)){
+                      cause=NNS.caus(x[,i],y,tau=0,plot=FALSE)
+                      x.star.coef[i]=cause[1]-cause[2]
+                    }
+                  }
+
+                  if(dim.red.method=="both"){
+                    x.star.coef.1=numeric()
+                    for(i in 1:ncol(x)){
+                      cause=NNS.caus(x[,i],y,tau=0,plot=FALSE)
+                      x.star.coef.1[i]=cause[1]-cause[2]
+                    }
+                    x.star.coef.2 = x.star.dep$Correlation[-(ncol(x)+1),(ncol(x)+1)]
+                    x.star.coef = rowMeans(cbind(x.star.coef.1,x.star.coef.2))
+                  }
+
                   x.star.dep = x.star.dep$Dependence[-(ncol(x)+1),(ncol(x)+1)]
 
                   x.star.coef[abs(x.star.coef)<threshold]<- 0
@@ -220,7 +261,8 @@ NNS.reg = function (x,y,
     dependence = (NNS.dep(x,y,print.map = F)$Dependence)^(1/3)
 
   } else {
-    if(type=="CLASS") dependence=(mean(x.star.dep))^(1/3)}
+
+    if(dim.red==TRUE) dependence=(mean(x.star.dep))^(1/3)}
 
   if(is.null(order)){
       dep.reduced.order=floor(NNS.part(x,y,order='max')$order*dependence)}
